@@ -1,5 +1,6 @@
 import logging
 import os
+from os.path import getsize
 from shutil import copyfile
 
 from django.conf import settings
@@ -56,13 +57,13 @@ class CryptoManager(CommonManagetWithLookUpFieldsManager):
 
 
 class Crypto_file(AuditModel):
-    format = NameField(verbose_name='Формат файла')
-    mime_type = NameField(verbose_name='MIME тип файла файла')
-    size = BigIntegerField(verbose_name='Размер фала', default=0)
-    real_name = TextField(verbose_name='Первоначальное имя файла', db_index=True, unique=True)
-    key = BinaryField(max_length=200, null=True, blank=True)
     attfile = FileFieldEx(verbose_name='Файл', max_length=255)
     file_store = CharField(verbose_name='Каталог хранения файла', max_length=255, null=True, blank=True)
+    format = NameField(verbose_name='Формат файла')
+    key = BinaryField(max_length=200, null=True, blank=True)
+    mime_type = NameField(verbose_name='MIME тип файла файла')
+    real_name = TextField(verbose_name='Первоначальное имя файла', db_index=True, unique=True)
+    size = BigIntegerField(verbose_name='Размер файла', default=0)
 
     object = CryptoManager()
 
@@ -71,6 +72,29 @@ class Crypto_file(AuditModel):
         ls = self.real_name.split('\\')
         return ls[len(ls) - 1]
 
+    @classmethod
+    def exists(cls, filename):
+        if isinstance(settings.REPLACE_FILE_PATH, dict):
+            for key, value in settings.REPLACE_FILE_PATH.items():
+                filename = filename.replace(key, value)
+        res = os.path.exists(filename)
+        if res is False:
+            logger.debug(f'file: {filename} not exists.')
+        return filename, res
+
+    @classmethod
+    def check_file(cls, attfile):
+        if attfile is None or attfile == '':
+            return False, attfile
+        else:
+            filename = str(attfile)
+
+            filename, res = cls.exists(filename)
+            if res is True:
+                if getsize(filename) == 0:
+                    return filename, False
+            return filename, res
+
     @classmethod
     def remove_file(cls, item):
         old_file_store = item.file_store
@@ -98,7 +122,8 @@ class Crypto_file(AuditModel):
         if os.path.exists(item.real_file_name):
             copyfile(src=item.real_file_name, dst=item.full_path)
         else:
-            copyfile(src=item.tmp_file_name, dst=item.full_path)
+            if item.tmp_file_name is not None and os.path.exists(item.tmp_file_name):
+                copyfile(src=item.tmp_file_name, dst=item.full_path)
         with open(item.full_path, 'rb') as src:
             fileObj = File(src)
             res, created = cls.objects.update_or_create(
@@ -113,8 +138,9 @@ class Crypto_file(AuditModel):
                 )
             )
 
-        if os.path.exists(item.tmp_file_name):
+        if item.tmp_file_name is not None and os.path.exists(item.tmp_file_name):
             os.remove(item.tmp_file_name)
+            os.remove(item.full_path)
 
         return res, created
 
