@@ -22,6 +22,11 @@ class User(AbstractUser):
         admin_user, _ = User.objects.get_or_create(username='admin', defaults=dict(password='admin'))
         return admin_user
 
+    @classmethod
+    def unknown(cls):
+        res, _ = cls.objects.get_or_create(username="unknown")
+        return res
+
     def __str__(self):
         return f"id: {self.id}, username: {self.username}, full_name: ({self.first_name} {self.middle_name} {self.last_name})"
 
