@@ -39,6 +39,7 @@ route_made = "route_made"
 route_made_error = "route_made_error"
 sht = "шт"
 started = "started"
+shirts = "shirts"
 started_another = "started_another"
 stoped = "stoped"
 transferred = "transferred"
@@ -69,7 +70,7 @@ def blinkString(text, blink=True, color="black", bold=False) -> Text:
     else:
         res = f'<div><font color="{color}"</font>{text}</div>'
 
-    if bold == True:
+    if bold is True:
         return f'<b>{res}</b>'
     else:
         return res
@@ -81,7 +82,7 @@ def blinkString1(text, blink=True, color="black", bold=True) -> Text:
     else:
         res = f'<blink><font color="{color}"</font>{text}</blink>'
 
-    if bold == True:
+    if bold is True:
         return f'<b>{res}</b>'
     else:
         return res
