@@ -1,5 +1,8 @@
-# from django.contrib.postgres.fields import JSONField
-from django.db.models import JSONField
+try:
+    from django.db.models import JSONField
+except ImportError:
+    from django.contrib.postgres.fields import JSONField
+
 from django.db.models import CharField
 
 from isc_common.fields import Field
