@@ -15,9 +15,8 @@ class FieldFileEx(FieldFile, Field):
 
     def open(self, mode='rb'):
         self._require_file()
-        if getattr(self, '_file', None) is None:
-            if isinstance(settings.REPLACE_FILE_PATH, dict):
-                for key, value in settings.REPLACE_FILE_PATH.items():
+        if isinstance(settings.REPLACE_FILE_PATH, dict):
+            for key, value in settings.REPLACE_FILE_PATH.items():
                     self.name = self.name.replace(key, value)
             self.file = self.storage.open(self.name, mode)
         else:
