@@ -196,26 +196,6 @@ class DSRequest(RPCRequest):
     def get_data_wrapped(self, excluded_keys=['grid'], cls=Wrapper):
         return cls(**self.get_data(excluded_keys=excluded_keys))
 
-    def get_transaction_data(self, excluded_keys=['grid']):
-        data = self.get_data(excluded_keys=excluded_keys)
-        if isinstance(data, dict):
-            transaction = data.get('transaction')
-            if isinstance(transaction, dict):
-                return transaction.get('operations')
-            else:
-                return [data]
-        return None
-
-    def get_transaction_old_data(self, excluded_keys=['grid']):
-        data = self.get_old_data(excluded_keys=excluded_keys)
-        if isinstance(data, dict):
-            transaction = data.get('transaction')
-            if isinstance(transaction, dict):
-                return transaction.get('operations')
-            else:
-                return [data]
-        return None
-
     def get_old_data(self, excluded_keys=['grid']):
         res = None
         if isinstance(self.json, dict):
@@ -250,6 +230,12 @@ class DSRequest(RPCRequest):
     def set_data(self, data):
         if isinstance(data, dict):
             setAttr(self.json, 'data', data)
+        else:
+            delAttr(self.json, 'data')
+
+    def update_data(self, data):
+        if isinstance(data, dict):
+            self.json.update(data)
 
     def set_sort_by(self, sort_by):
         if not isinstance(sort_by, list):
@@ -261,6 +247,8 @@ class DSRequest(RPCRequest):
         data = self.get_all_data(excluded_keys=excluded_keys)
         if isinstance(data, dict):
             setAttr(data, 'criteria', criteria)
+        else:
+            delAttr(data, 'criteria')
 
     def get_criteria(self, excluded_keys=['grid']):
         data = self.get_data(excluded_keys=excluded_keys)
