@@ -4,7 +4,7 @@ from django.db.models import Model
 
 from isc_common import setAttr, delAttr
 from isc_common.bit import TurnBitOn, TurnBitOff
-from isc_common.fields.code_field import CodeField
+from isc_common.fields.code_field import CodeStrictField
 from isc_common.fields.description_field import DescriptionField
 from isc_common.fields.name_field import NameField
 from isc_common.fields.related import ForeignKeyProtect
@@ -75,6 +75,7 @@ class BaseRefQuerySet(AuditQuerySet):
         res = super().create(**kwargs)
         return res
 
+
 class BaseRefHierarcyQuerySet(BaseRefQuerySet):
 
     def filter(self, *args, **kwargs):
@@ -136,12 +137,14 @@ class BaseRefHierarcyQuerySet(BaseRefQuerySet):
         res = super().create(**kwargs)
         return res
 
+
 class BaseRefManager(AuditManager):
     def get_queryset(self):
         if self.alive_only:
             return BaseRefQuerySet(model=self.model, alive_only=self.alive_only).filter(deleted_at=None)
         return BaseRefQuerySet(model=self.model, alive_only=False)
 
+
 class BaseRefHierarcyManager(AuditManager):
     def get_queryset(self):
         if self.alive_only:
@@ -186,7 +189,7 @@ class StatusBaseRefManager(BaseRefManager):
 
 
 class BaseRef(AuditModel):
-    code = CodeField()
+    code = CodeStrictField(unique=True)
     name = NameField()
     description = DescriptionField()
 
@@ -263,7 +266,7 @@ class Hierarcy(AuditModel, BaseHierarcy):
 
 
 class BaseRefHierarcy(Hierarcy):
-    code = CodeField(db_index=True)
+    code = CodeStrictField(db_index=True)
     name = NameField()
     description = DescriptionField()
 
