@@ -1,5 +1,6 @@
 import logging
 import os
+from os.path import getsize
 
 from django.conf import settings
 
@@ -68,6 +69,7 @@ class Model_images(AuditModel):
         from isc_common.models.image_types import Image_types
         from isc_common.models.images import Images
         from lfl_admin.common.models.site_lfl_images import Site_lfl_images
+        from isc_common.ssh.ssh_client import SSH_Client
 
         if name is None:
             name = code
@@ -83,17 +85,24 @@ class Model_images(AuditModel):
             image_type, created = Image_types.objects.get_or_create(code=code, defaults=dict(name=name))
             image, created = Images.objects.update_or_create(image_type=image_type, real_name=full_name_image)
 
-            if os.path.exists(full_name_image):
-                image1, created = Images.create_update(id=image.id, image_type=image_type, real_file_name=full_name_image)
+            zero = False
+            full_name_image_replaced = full_name_image.replace(settings.PATH_IMAGES_REPLACE.get('old_path'), settings.PATH_IMAGES_REPLACE.get('new_path'))
+            full_name_image_replaced = full_name_image_replaced.replace(os.altsep if os.altsep is not None else '\\', os.sep)
+
+            if os.path.exists(full_name_image_replaced):
+                image1, created = Images.create_update(id=image.id, image_type=image_type, real_file_name=full_name_image_replaced)
 
             elif update_from_sftp is True:
-                full_name_image_replaced = full_name_image.replace(settings.PATH_IMAGES_REPLACE.get('old_path'), settings.PATH_IMAGES_REPLACE.get('new_path'))
-                full_name_image_replaced = full_name_image_replaced.replace(os.altsep if os.altsep is not None else '\\', os.sep)
                 file_name = os.path.split(full_name_image_replaced)[1]
                 localpath = f"{settings.PATH_IMAGES_REPLACE.get('tmp_path')}{file_name}"
-                settings.SSH_CLIENT.get(remotepath=full_name_image_replaced, localpath=localpath)
+                SSH_CLIENT = SSH_Client(hostname=settings.SSH_HOST, username=settings.SSH_USER, password=settings.SSH_PASSWORD)
+                SSH_CLIENT.get(remotepath=full_name_image_replaced, localpath=localpath)
 
-                if os.path.exists(localpath):
+                if getsize(localpath) == 0:
+                    os.remove(localpath)
+                    logger.debug(f'{localpath} is zero size')
+                    zero = True
+                elif os.path.exists(localpath):
                     image1, created = Images.create_update(
                         id=image.id,
                         image_type=image_type,
@@ -101,12 +110,13 @@ class Model_images(AuditModel):
                         tmp_file_name=localpath
                     )
 
-            if self_image_field is False:
-                return cls.objects.update_or_create(image=image, main_model=main_model, defaults=defaults)
-            else:
-                eval(f'main_model._meta.concrete_model.objects.filter({pk_name}=main_model.{pk_name}).update({image_field_name}=image)', dict(), dict(image=image, main_model=main_model))
+            if not zero:
+                if self_image_field is False:
+                    return cls.objects.update_or_create(image=image, main_model=main_model, defaults=defaults)
+                else:
+                    eval(f'main_model._meta.concrete_model.objects.filter({pk_name}=main_model.{pk_name}).update({image_field_name}=image)', dict(), dict(image=image, main_model=main_model))
 
-            logger.debug(f'{file_name} : found')
+                logger.debug(f'{file_name} : found')
 
         elif file_name is not None:
             if exception is True:
