@@ -1,5 +1,3 @@
-from django.utils.translation import ugettext_lazy as _
-
 import logging
 
 from isc_common.fields.code_field import ColorField
@@ -32,7 +30,7 @@ class Standard_colorsManager(BaseRefManager):
 
 
 class Standard_colors(BaseRef):
-    color = ColorField()
+    color = ColorField(null=True, blank=True)
     objects = Standard_colorsManager()
 
     def __str__(self):
