@@ -11,14 +11,7 @@ logger = logging.getLogger(__name__)
 
 
 class Users_imagesQuerySet(Model_imagesQuerySet):
-    def delete(self):
-        return super().delete()
-
-    def create(self, **kwargs):
-        return super().create(**kwargs)
-
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    pass
 
 
 class Users_imagesManager(Model_imagesManager):
